summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKevin P. Fleming <kpfleming@digium.com>2008-05-21 16:59:46 +0000
committerKevin P. Fleming <kpfleming@digium.com>2008-05-21 16:59:46 +0000
commitc6c6804d72cad2eef6d44974534fd79f173c8214 (patch)
treefaccd10843aaba2fe0da85d57cd91cb36b314b6b
parent3b10699608036b8dfab80e25efe1bee493786413 (diff)
replace Zaptel with DAHDI, ZAPTEL with DAHDI, ZAPATA with DAHDI
git-svn-id: http://svn.asterisk.org/svn/dahdi/linux/trunk@4322 a0bf4364-ded3-4de4-8d8a-66a801d63aff
-rw-r--r--Makefile6
-rwxr-xr-xbuild_tools/make_version_h2
-rw-r--r--drivers/dahdi/Kbuild4
-rw-r--r--drivers/dahdi/arith.h8
-rw-r--r--drivers/dahdi/dahdi-base.c148
-rw-r--r--drivers/dahdi/dahdi_config.h24
-rw-r--r--drivers/dahdi/dahdi_dummy.c22
-rw-r--r--drivers/dahdi/dahdi_dummy.h2
-rw-r--r--drivers/dahdi/dahdi_dynamic.c8
-rw-r--r--drivers/dahdi/dahdi_dynamic_eth.c4
-rw-r--r--drivers/dahdi/dahdi_dynamic_loc.c2
-rw-r--r--drivers/dahdi/dahdi_transcode.c8
-rw-r--r--drivers/dahdi/hpec/hpec_dahdi.h8
-rw-r--r--drivers/dahdi/jpah.h2
-rw-r--r--drivers/dahdi/kb1ec.h2
-rw-r--r--drivers/dahdi/mg2ec.h2
-rw-r--r--drivers/dahdi/pciradio.c6
-rw-r--r--drivers/dahdi/sec-2.h6
-rw-r--r--drivers/dahdi/sec.h6
-rw-r--r--drivers/dahdi/tor2.c4
-rw-r--r--drivers/dahdi/wcfxo.c2
-rw-r--r--drivers/dahdi/wct1xxp.c2
-rw-r--r--drivers/dahdi/wct4xxp/base.c2
-rw-r--r--drivers/dahdi/wctc4xxp/base.c2
-rw-r--r--drivers/dahdi/wctc4xxp/codec_test.c2
-rw-r--r--drivers/dahdi/wctdm.c2
-rw-r--r--drivers/dahdi/wctdm24xxp/base.c2
-rw-r--r--drivers/dahdi/wcte11xp.c2
-rw-r--r--drivers/dahdi/wcte12xp/base.c2
-rw-r--r--include/dahdi/kernel.h32
30 files changed, 162 insertions, 162 deletions
diff --git a/Makefile b/Makefile
index 1f47982..d4d67aa 100644
--- a/Makefile
+++ b/Makefile
@@ -118,10 +118,10 @@ ifneq (,$(NETSCR_DIR))
endif
ifneq ($(wildcard .version),)
- ZAPTELVERSION:=$(shell cat .version)
+ DAHDIVERSION:=$(shell cat .version)
else
ifneq ($(wildcard .svn),)
- ZAPTELVERSION=SVN-$(shell build_tools/make_svn_branch_name)
+ DAHDIVERSION=SVN-$(shell build_tools/make_svn_branch_name)
endif
endif
@@ -135,7 +135,7 @@ endif
$(KMAKE) modules
version.h:
- @ZAPTELVERSION="${ZAPTELVERSION}" build_tools/make_version_h > $@.tmp
+ @DAHDIVERSION="${DAHDIVERSION}" build_tools/make_version_h > $@.tmp
@if cmp -s $@.tmp $@ ; then :; else \
mv $@.tmp $@ ; \
fi
diff --git a/build_tools/make_version_h b/build_tools/make_version_h
index 01d9c31..a35dd8a 100755
--- a/build_tools/make_version_h
+++ b/build_tools/make_version_h
@@ -4,6 +4,6 @@ cat << END
* version.h
* Automatically generated
*/
-#define ZAPTEL_VERSION "${ZAPTELVERSION}"
+#define DAHDI_VERSION "${DAHDIVERSION}"
END
diff --git a/drivers/dahdi/Kbuild b/drivers/dahdi/Kbuild
index 84a7372..d6b8d5e 100644
--- a/drivers/dahdi/Kbuild
+++ b/drivers/dahdi/Kbuild
@@ -52,7 +52,7 @@ $(obj)/radfw.h: $(src)/pciradio.rbt $(obj)/makefw
$(obj)/makefw: $(src)/makefw.c
$(HOSTCC) -o $@ $^
-# set CONFIG_ZAPTEL_MMX for a number of CPU types.
+# set CONFIG_DAHDI_MMX for a number of CPU types.
# Right now this part is not enabled, unless you build with
# ZAPTEL_MMX_AUTO=something .
ZAPMMX_WHITELIST_i386 = M586MMX M686 MPENTIUMII MPENTIUMIII MPENTIUMM \
@@ -68,6 +68,6 @@ ZAPMMX_CONFIG_VALS := $(strip $(foreach var,$(ZAPMMX_CONFIG_VARS),$(var)) )
ifneq (,$(ZAPTEL_MMX_AUTO))
ifneq (,$(ZAPMMX_CONFIG_VALS))
# TODO: make that
- CFLAGS_dahdi-base.o += -DCONFIG_ZAPTEL_MMX
+ CFLAGS_dahdi-base.o += -DCONFIG_DAHDI_MMX
endif
endif
diff --git a/drivers/dahdi/arith.h b/drivers/dahdi/arith.h
index 760dcc8..9f763fe 100644
--- a/drivers/dahdi/arith.h
+++ b/drivers/dahdi/arith.h
@@ -1,12 +1,12 @@
-#ifndef _ZAPTEL_ARITH_H
-#define _ZAPTEL_ARITH_H
+#ifndef _DAHDI_ARITH_H
+#define _DAHDI_ARITH_H
/*
* Handy add/subtract functions to operate on chunks of shorts.
* Feel free to add customizations for additional architectures
*
*/
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
#ifdef DAHDI_CHUNKSIZE
static inline void __ACSS(volatile short *dst, const short *src)
{
@@ -361,4 +361,4 @@ static inline short MAX16(const short *y, int len, int *pos)
}
#endif /* MMX */
-#endif /* _ZAPTEL_ARITH_H */
+#endif /* _DAHDI_ARITH_H */
diff --git a/drivers/dahdi/dahdi-base.c b/drivers/dahdi/dahdi-base.c
index 4a065a9..34eb2ae 100644
--- a/drivers/dahdi/dahdi-base.c
+++ b/drivers/dahdi/dahdi-base.c
@@ -50,11 +50,11 @@
#ifdef CONFIG_DEVFS_FS
#include <linux/devfs_fs_kernel.h>
#endif /* CONFIG_DEVFS_FS */
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
#include <linux/netdevice.h>
-#endif /* CONFIG_ZAPATA_NET */
+#endif /* CONFIG_DAHDI_NET */
#include <linux/ppp_defs.h>
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
#include <linux/netdevice.h>
#include <linux/if.h>
#include <linux/if_ppp.h>
@@ -88,7 +88,7 @@
/* Get helper arithmetic */
#include "arith.h"
-#if defined(CONFIG_ZAPTEL_MMX) || defined(ECHO_CAN_FP)
+#if defined(CONFIG_DAHDI_MMX) || defined(ECHO_CAN_FP)
#include <asm/i387.h>
#endif
@@ -317,7 +317,7 @@ static struct dahdi_dialparams global_dialparams = {
static int dahdi_chan_ioctl(struct inode *inode, struct file *file, unsigned int cmd, unsigned long data, int unit);
-#if defined(CONFIG_ZAPTEL_MMX) || defined(ECHO_CAN_FP)
+#if defined(CONFIG_DAHDI_MMX) || defined(ECHO_CAN_FP)
/* XXX kernel_fpu_begin() is NOT exported properly (in 2.4), so we have to make
a local version. Somebody fix this! XXX */
@@ -1022,7 +1022,7 @@ static void close_channel(struct dahdi_chan *chan)
struct echo_can_state *ec = NULL;
int oldconf;
short *readchunkpreec;
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
struct ppp_channel *ppp;
#endif
@@ -1030,7 +1030,7 @@ static void close_channel(struct dahdi_chan *chan)
if (!(chan->flags & DAHDI_FLAG_NOSTDTXRX))
dahdi_reallocbufs(chan, 0, 0);
spin_lock_irqsave(&chan->lock, flags);
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
ppp = chan->ppp;
chan->ppp = NULL;
#endif
@@ -1103,7 +1103,7 @@ static void close_channel(struct dahdi_chan *chan)
if (readchunkpreec)
kfree(readchunkpreec);
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (ppp) {
tasklet_kill(&chan->ppp_calls);
skb_queue_purge(&chan->ppp_rq);
@@ -1415,10 +1415,10 @@ char *dahdi_lboname(int x)
return dahdi_txlevelnames[x];
}
-#if defined(CONFIG_ZAPATA_NET) || defined(CONFIG_ZAPATA_PPP)
+#if defined(CONFIG_DAHDI_NET) || defined(CONFIG_DAHDI_PPP)
#endif
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
#ifdef NEW_HDLC_INTERFACE
static int dahdi_net_open(struct net_device *dev)
{
@@ -1468,7 +1468,7 @@ static int dahdi_net_open(hdlc_device *hdlc)
#ifndef LINUX26
MOD_INC_USE_COUNT;
#endif
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("ZAPNET: Opened channel %d name %s\n", ms->channo, ms->name);
#endif
return 0;
@@ -1657,7 +1657,7 @@ static int dahdi_xmit(hdlc_device *hdlc, struct sk_buff *skb)
dev->trans_start = jiffies;
stats->tx_packets++;
stats->tx_bytes += ss->writen[oldbuf];
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Buffered %d bytes to go out in buffer %d\n", ss->writen[oldbuf], oldbuf);
for (x=0;x<ss->writen[oldbuf];x++)
printk("%02x ", ss->writebuf[oldbuf][x]);
@@ -1685,7 +1685,7 @@ static int dahdi_net_ioctl(hdlc_device *hdlc, struct ifreq *ifr, int cmd)
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
static int dahdi_ppp_xmit(struct ppp_channel *ppp, struct sk_buff *skb)
{
@@ -1758,7 +1758,7 @@ static int dahdi_ppp_xmit(struct ppp_channel *ppp, struct sk_buff *skb)
some space for us */
ss->outwritebuf = oldbuf;
}
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Buffered %d bytes (skblen = %d) to go out in buffer %d\n", ss->writen[oldbuf], skb->len, oldbuf);
for (x=0;x<ss->writen[oldbuf];x++)
printk("%02x ", ss->writebuf[oldbuf][x]);
@@ -1793,7 +1793,7 @@ static void dahdi_chan_unreg(struct dahdi_chan *chan)
{
int x;
unsigned long flags;
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (chan->flags & DAHDI_FLAG_NETDEV) {
#ifdef LINUX26
unregister_hdlc_device(chan->hdlcnetdev->netdev);
@@ -1810,7 +1810,7 @@ static void dahdi_chan_unreg(struct dahdi_chan *chan)
chans[chan->channo] = NULL;
chan->flags &= ~DAHDI_FLAG_REGISTERED;
}
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (chan->ppp) {
printk("HUH??? PPP still attached??\n");
}
@@ -1987,7 +1987,7 @@ static ssize_t dahdi_chan_write(struct file *file, const char *usrbuf, size_t co
amnt = chan->blocksize;
}
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("dahdi_chan_write(unit: %d, res: %d, outwritebuf: %d amnt: %d\n",
unit, chan->res, chan->outwritebuf, amnt);
#endif
@@ -2186,7 +2186,7 @@ who cares what the sig bits are as long as they are stable */
} else {
for (x=0;x<NUM_SIGS;x++) {
if (outs[x][0] == chan->sig) {
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Setting bits to %d for channel %s state %d in %d signalling\n", outs[x][txsig + 1], chan->name, txsig, chan->sig);
#endif
chan->txhooksig = txsig;
@@ -3184,7 +3184,7 @@ void dahdi_alarm_notify(struct dahdi_span *span)
for (x=1; x<maxspans; x++) {
if (spans[x] && !spans[x]->alarms && (spans[x]->flags & DAHDI_FLAG_RUNNING)) {
if(master != spans[x])
- printk("Zaptel: Master changed to %s\n", spans[x]->name);
+ printk("DAHDI: Master changed to %s\n", spans[x]->name);
master = spans[x];
break;
}
@@ -3542,7 +3542,7 @@ static int dahdi_common_ioctl(struct inode *node, struct file *file, unsigned in
/* release it. */
spin_unlock_irqrestore(&chans[j]->lock, flags);
- printk(KERN_INFO "Dump of Zaptel Channel %d (%s,%d,%d):\n\n",j,
+ printk(KERN_INFO "Dump of DAHDI Channel %d (%s,%d,%d):\n\n",j,
mychan->name,mychan->channo,mychan->chanpos);
printk(KERN_INFO "flags: %x hex, writechunk: %08lx, readchunk: %08lx\n",
(unsigned int) mychan->flags, (long) mychan->writechunk, (long) mychan->readchunk);
@@ -3602,14 +3602,14 @@ static void recalc_slaves(struct dahdi_chan *chan)
if (!chan->span)
return;
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Recalculating slaves on %s\n", chan->name);
#endif
/* Link all slaves appropriately */
for (x=chan->chanpos;x<chan->span->channels;x++)
if (chan->span->chans[x].master == chan) {
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Channel %s, slave to %s, last is %s, its next will be %d\n",
chan->span->chans[x].name, chan->name, last->name, x);
#endif
@@ -3618,7 +3618,7 @@ static void recalc_slaves(struct dahdi_chan *chan)
}
/* Terminate list */
last->nextslave = 0;
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Done Recalculating slaves on %s (last is %s)\n", chan->name, last->name);
#endif
}
@@ -3712,7 +3712,7 @@ static int dahdi_ctl_ioctl(struct inode *inode, struct file *file, unsigned int
newmaster = chans[ch.chan];
}
spin_lock_irqsave(&chans[ch.chan]->lock, flags);
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (chans[ch.chan]->flags & DAHDI_FLAG_NETDEV) {
if (ztchan_to_dev(chans[ch.chan])->flags & IFF_UP) {
spin_unlock_irqrestore(&chans[ch.chan]->lock, flags);
@@ -3734,7 +3734,7 @@ static int dahdi_ctl_ioctl(struct inode *inode, struct file *file, unsigned int
#else
if (ch.sigtype == DAHDI_SIG_HDLCNET) {
spin_unlock_irqrestore(&chans[ch.chan]->lock, flags);
- printk(KERN_WARNING "Zaptel networking not supported by this build.\n");
+ printk(KERN_WARNING "DAHDI networking not supported by this build.\n");
return -ENOSYS;
}
#endif
@@ -3812,7 +3812,7 @@ static int dahdi_ctl_ioctl(struct inode *inode, struct file *file, unsigned int
else
chans[ch.chan]->flags &= ~DAHDI_FLAG_MTP2;
}
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (!res &&
(newmaster == chans[ch.chan]) &&
(chans[ch.chan]->sig == DAHDI_SIG_HDLCNET)) {
@@ -3889,7 +3889,7 @@ static int dahdi_ctl_ioctl(struct inode *inode, struct file *file, unsigned int
if (y >= 0) chans[ch.chan]->rxsig = (unsigned char)y;
chans[ch.chan]->rxhooksig = DAHDI_RXSIG_INITIAL;
}
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Configured channel %s, flags %04x, sig %04x\n", chans[ch.chan]->name, chans[ch.chan]->flags, chans[ch.chan]->sig);
#endif
spin_unlock_irqrestore(&chans[ch.chan]->lock, flags);
@@ -3999,7 +3999,7 @@ static int dahdi_ctl_ioctl(struct inode *inode, struct file *file, unsigned int
struct dahdi_versioninfo vi;
memset(&vi, 0, sizeof(vi));
- dahdi_copy_string(vi.version, ZAPTEL_VERSION, sizeof(vi.version));
+ dahdi_copy_string(vi.version, DAHDI_VERSION, sizeof(vi.version));
echo_can_identify(vi.echo_canceller, sizeof(vi.echo_canceller) - 1);
if (copy_to_user((struct dahdi_versioninfo *) data, &vi, sizeof(vi)))
return -EFAULT;
@@ -4616,7 +4616,7 @@ static int dahdi_chanandpseudo_ioctl(struct inode *inode, struct file *file, uns
return 0;
}
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
/*
* This is called at softirq (BH) level when there are calls
* we need to make to the ppp_generic layer. We do it this
@@ -4824,7 +4824,7 @@ static int dahdi_chan_ioctl(struct inode *inode, struct file *file, unsigned int
}
break;
case DAHDI_HDLCPPP:
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (chan->sig != DAHDI_SIG_CLEAR) return (-EINVAL);
get_user(j, (int *)data);
if (j) {
@@ -4885,7 +4885,7 @@ static int dahdi_chan_ioctl(struct inode *inode, struct file *file, unsigned int
}
}
#else
- printk("Zaptel: Zaptel PPP support not compiled in\n");
+ printk("DAHDI: DAHDI PPP support not compiled in\n");
return -ENOSYS;
#endif
break;
@@ -5071,7 +5071,7 @@ static int dahdi_chan_ioctl(struct inode *inode, struct file *file, unsigned int
} else
return -ENOSYS;
break;
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
case PPPIOCGCHAN:
if (chan->flags & DAHDI_FLAG_PPP)
return put_user(ppp_channel_index(chan->ppp), (int *)data) ? -EFAULT : 0;
@@ -5806,11 +5806,11 @@ out in the later versions, and is put back now. */
/* Transmit a flag if this is an HDLC channel */
if (ms->flags & DAHDI_FLAG_HDLC)
fasthdlc_tx_frame_nocheck(&ms->txhdlc);
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (ms->flags & DAHDI_FLAG_NETDEV)
netif_wake_queue(ztchan_to_dev(ms));
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (ms->flags & DAHDI_FLAG_PPP) {
ms->do_ppp_wakeup = 1;
tasklet_schedule(&ms->ppp_calls);
@@ -6169,7 +6169,7 @@ static void __dahdi_hooksig_pvt(struct dahdi_chan *chan, dahdi_rxsig_t rxsig)
dahdi_rbs_sethook(chan,DAHDI_TXSIG_OFFHOOK, DAHDI_TXSTATE_AFTERSTART, DAHDI_AFTERSTART_TIME);
}
chan->kewlonhook = 0;
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Off hook on channel %d, itimer = %d, gotgs = %d\n", chan->channo, chan->itimer, chan->gotgs);
#endif
if (chan->itimer) /* if timer still running */
@@ -6297,7 +6297,7 @@ static inline void __dahdi_ec_chunk(struct dahdi_chan *ss, unsigned char *rxchun
/* Perform echo cancellation on a chunk if necessary */
if (ss->ec) {
-#if defined(CONFIG_ZAPTEL_MMX) || defined(ECHO_CAN_FP)
+#if defined(CONFIG_DAHDI_MMX) || defined(ECHO_CAN_FP)
dahdi_kernel_fpu_begin();
#endif
if (ss->echostate & __ECHO_STATE_MUTE) {
@@ -6344,7 +6344,7 @@ static inline void __dahdi_ec_chunk(struct dahdi_chan *ss, unsigned char *rxchun
rxchunk[x] = DAHDI_LIN2X((int) rxlins[x], ss);
#endif /* defined(DAHDI_EC_ARRAY_UPDATE) */
}
-#if defined(CONFIG_ZAPTEL_MMX) || defined(ECHO_CAN_FP)
+#if defined(CONFIG_DAHDI_MMX) || defined(ECHO_CAN_FP)
kernel_fpu_end();
#endif
}
@@ -6674,7 +6674,7 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
struct dahdi_chan *ms = ss->master;
/* Our receive buffer */
unsigned char *buf;
-#if defined(CONFIG_ZAPATA_NET) || defined(CONFIG_ZAPATA_PPP)
+#if defined(CONFIG_DAHDI_NET) || defined(CONFIG_DAHDI_PPP)
/* SKB for receiving network stuff */
struct sk_buff *skb=NULL;
#endif
@@ -6685,7 +6685,7 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
int left, x;
while(bytes) {
-#if defined(CONFIG_ZAPATA_NET) || defined(CONFIG_ZAPATA_PPP)
+#if defined(CONFIG_DAHDI_NET) || defined(CONFIG_DAHDI_PPP)
skb = NULL;
#endif
abort = 0;
@@ -6759,13 +6759,13 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
oldbuf = ms->inreadbuf;
ms->infcs = PPP_INITFCS;
ms->readn[ms->inreadbuf] = ms->readidx[ms->inreadbuf];
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("EOF, len is %d\n", ms->readn[ms->inreadbuf]);
#endif
-#if defined(CONFIG_ZAPATA_NET) || defined(CONFIG_ZAPATA_PPP)
+#if defined(CONFIG_DAHDI_NET) || defined(CONFIG_DAHDI_PPP)
if (ms->flags & (DAHDI_FLAG_NETDEV | DAHDI_FLAG_PPP)) {
-#ifdef CONFIG_ZAPATA_NET
-#endif /* CONFIG_ZAPATA_NET */
+#ifdef CONFIG_DAHDI_NET
+#endif /* CONFIG_DAHDI_NET */
/* Our network receiver logic is MUCH
different. We actually only use a single
buffer */
@@ -6773,7 +6773,7 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
/* Drop the FCS */
ms->readn[ms->inreadbuf] -= 2;
/* Allocate an SKB */
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (!ms->do_ppp_error)
#endif
skb = dev_alloc_skb(ms->readn[ms->inreadbuf]);
@@ -6781,7 +6781,7 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
/* XXX Get rid of this memcpy XXX */
memcpy(skb->data, ms->readbuf[ms->inreadbuf], ms->readn[ms->inreadbuf]);
skb_put(skb, ms->readn[ms->inreadbuf]);
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (ms->flags & DAHDI_FLAG_NETDEV) {
#ifdef LINUX26
struct net_device_stats *stats = hdlc_stats(ms->hdlcnetdev->netdev);
@@ -6794,7 +6794,7 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
#endif
} else {
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (ms->flags & DAHDI_FLAG_NETDEV) {
#ifdef LINUX26
struct net_device_stats *stats = hdlc_stats(ms->hdlcnetdev->netdev);
@@ -6804,13 +6804,13 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
stats->rx_dropped++;
}
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (ms->flags & DAHDI_FLAG_PPP) {
abort = DAHDI_EVENT_OVERRUN;
}
#endif
#if 1
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (!ms->do_ppp_error)
#endif
printk("Memory squeeze, dropped one\n");
@@ -6848,7 +6848,7 @@ static inline void __putbuf_chunk(struct dahdi_chan *ss, unsigned char *rxb, int
/* Whoops, we're full, and have no where else
to store into at the moment. We'll drop it
until there's a buffer available */
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Out of storage space\n");
#endif
ms->inreadbuf = -1;
@@ -6871,7 +6871,7 @@ out in the later versions, and is put back now. */
if (!ms->rxdisable) { /* if receiver enabled */
/* Notify a blocked reader that there is data available
to be read, unless we're waiting for it to be full */
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Notifying reader data in block %d\n", oldbuf);
#endif
wake_up_interruptible(&ms->readbufq);
@@ -6887,7 +6887,7 @@ out in the later versions, and is put back now. */
ms->readidx[ms->inreadbuf] = 0;
ms->infcs = PPP_INITFCS;
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (ms->flags & DAHDI_FLAG_NETDEV) {
#ifdef LINUX26
struct net_device_stats *stats = hdlc_stats(ms->hdlcnetdev->netdev);
@@ -6903,7 +6903,7 @@ out in the later versions, and is put back now. */
stats->rx_frame_errors++;
} else
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (ms->flags & DAHDI_FLAG_PPP) {
ms->do_ppp_error = 1;
tasklet_schedule(&ms->ppp_calls);
@@ -6920,7 +6920,7 @@ out in the later versions, and is put back now. */
}
} else /* No place to receive -- drop on the floor */
break;
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
if (skb && (ms->flags & DAHDI_FLAG_NETDEV))
#ifdef NEW_HDLC_INTERFACE
{
@@ -6941,7 +6941,7 @@ out in the later versions, and is put back now. */
hdlc_netif_rx(&ms->hdlcnetdev->netdev, skb);
#endif
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
if (skb && (ms->flags & DAHDI_FLAG_PPP)) {
unsigned char *tmp;
tmp = skb->data;
@@ -6990,7 +6990,7 @@ extern void dahdi_hdlc_putbuf(struct dahdi_chan *ss, unsigned char *rxb, int byt
spin_lock_irqsave(&ss->lock, flags);
if (ss->inreadbuf < 0) {
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("No place to receive HDLC frame\n");
#endif
spin_unlock_irqrestore(&ss->lock, flags);
@@ -7008,7 +7008,7 @@ extern void dahdi_hdlc_putbuf(struct dahdi_chan *ss, unsigned char *rxb, int byt
}
/* Something isn't fit into buffer */
if (bytes) {
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("HDLC frame isn't fit into buffer space\n");
#endif
__dahdi_hdlc_abort(ss, DAHDI_EVENT_OVERRUN);
@@ -7025,7 +7025,7 @@ extern void dahdi_hdlc_finish(struct dahdi_chan *ss)
spin_lock_irqsave(&ss->lock, flags);
if ((oldreadbuf = ss->inreadbuf) < 0) {
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("No buffers to finish\n");
#endif
spin_unlock_irqrestore(&ss->lock, flags);
@@ -7033,7 +7033,7 @@ extern void dahdi_hdlc_finish(struct dahdi_chan *ss)
}
if (!ss->readidx[ss->inreadbuf]) {
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Empty HDLC frame received\n");
#endif
spin_unlock_irqrestore(&ss->lock, flags);
@@ -7044,7 +7044,7 @@ extern void dahdi_hdlc_finish(struct dahdi_chan *ss)
ss->inreadbuf = (ss->inreadbuf + 1) % ss->numbufs;
if (ss->inreadbuf == ss->outreadbuf) {
ss->inreadbuf = -1;
-#ifdef CONFIG_ZAPATA_DEBUG
+#ifdef CONFIG_DAHDI_DEBUG
printk("Notifying reader data in block %d\n", oldreadbuf);
#endif
ss->rxdisable = 0;
@@ -7242,11 +7242,11 @@ static void __dahdi_transmit_chunk(struct dahdi_chan *chan, unsigned char *buf)
__dahdi_getbuf_chunk(chan, buf);
if ((chan->flags & DAHDI_FLAG_AUDIO) || (chan->confmode)) {
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
dahdi_kernel_fpu_begin();
#endif
__dahdi_process_getaudio_chunk(chan, buf);
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
kernel_fpu_end();
#endif
}
@@ -7327,11 +7327,11 @@ static void __dahdi_receive_chunk(struct dahdi_chan *chan, unsigned char *buf)
buf = waste;
}
if ((chan->flags & DAHDI_FLAG_AUDIO) || (chan->confmode)) {
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
dahdi_kernel_fpu_begin();
#endif
__dahdi_process_putaudio_chunk(chan, buf);
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
kernel_fpu_end();
#endif
}
@@ -7430,7 +7430,7 @@ int dahdi_receive(struct dahdi_span *span)
unsigned long flags, flagso;
#if 1
-#ifdef CONFIG_ZAPTEL_WATCHDOG
+#ifdef CONFIG_DAHDI_WATCHDOG
span->watchcounter--;
#endif
for (x=0;x<span->channels;x++) {
@@ -7538,7 +7538,7 @@ int dahdi_receive(struct dahdi_span *span)
}
}
if (maxlinks) {
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
dahdi_kernel_fpu_begin();
#endif
/* process all the conf links */
@@ -7549,7 +7549,7 @@ int dahdi_receive(struct dahdi_span *span)
ACSS(conf_sums[z], conf_sums[y]);
}
}
-#ifdef CONFIG_ZAPTEL_MMX
+#ifdef CONFIG_DAHDI_MMX
kernel_fpu_end();
#endif
}
@@ -7574,7 +7574,7 @@ int dahdi_receive(struct dahdi_span *span)
spin_unlock_irqrestore(&chans[x]->lock, flags);
}
}
-#ifdef ZAPTEL_SYNC_TICK
+#ifdef DAHDI_SYNC_TICK
for (x=0;x<maxspans;x++) {
struct dahdi_span *s = spans[x];
@@ -7594,7 +7594,7 @@ MODULE_DESCRIPTION("Zapata Telephony Interface");
MODULE_LICENSE("GPL");
#endif
#ifdef MODULE_VERSION
-MODULE_VERSION(ZAPTEL_VERSION);
+MODULE_VERSION(DAHDI_VERSION);
#endif
#ifdef LINUX26
@@ -7620,7 +7620,7 @@ static struct file_operations dahdi_fops = {
fasync: NULL,
};
-#ifdef CONFIG_ZAPTEL_WATCHDOG
+#ifdef CONFIG_DAHDI_WATCHDOG
static struct timer_list watchdogtimer;
static void watchdog_check(unsigned long ignored)
@@ -7656,7 +7656,7 @@ static void watchdog_check(unsigned long ignored)
}
local_irq_restore(flags);
if (!wdcheck) {
- printk("Zaptel watchdog on duty!\n");
+ printk("DAHDI watchdog on duty!\n");
wdcheck=1;
}
mod_timer(&watchdogtimer, jiffies + 2);
@@ -7743,19 +7743,19 @@ static int __init dahdi_init(void) {
}
#else
if ((res = register_chrdev(DAHDI_MAJOR, "zaptel", &dahdi_fops))) {
- printk(KERN_ERR "Unable to register Zaptel character device handler on %d\n", DAHDI_MAJOR);
+ printk(KERN_ERR "Unable to register DAHDI character device handler on %d\n", DAHDI_MAJOR);
return res;
}
#endif /* CONFIG_DEVFS_FS */
printk(KERN_INFO "Zapata Telephony Interface Registered on major %d\n", DAHDI_MAJOR);
- printk(KERN_INFO "Zaptel Version: %s\n", ZAPTEL_VERSION);
+ printk(KERN_INFO "DAHDI Version: %s\n", DAHDI_VERSION);
echo_can_init();
dahdi_conv_init();
fasthdlc_precalc();
rotate_sums();
rwlock_init(&chan_lock);
-#ifdef CONFIG_ZAPTEL_WATCHDOG
+#ifdef CONFIG_DAHDI_WATCHDOG
watchdog_init();
#endif
return res;
@@ -7791,7 +7791,7 @@ static void __exit dahdi_cleanup(void) {
#endif /* CONFIG_DAHDI_UDEV */
unregister_chrdev(DAHDI_MAJOR, "zaptel");
#endif
-#ifdef CONFIG_ZAPTEL_WATCHDOG
+#ifdef CONFIG_DAHDI_WATCHDOG
watchdog_cleanup();
#endif
diff --git a/drivers/dahdi/dahdi_config.h b/drivers/dahdi/dahdi_config.h
index 84f8d21..997efb4 100644
--- a/drivers/dahdi/dahdi_config.h
+++ b/drivers/dahdi/dahdi_config.h
@@ -1,5 +1,5 @@
/*
- * Zaptel configuration options
+ * DAHDI configuration options
*
*/
#ifndef _ZCONFIG_H
@@ -14,7 +14,7 @@
#endif
#endif
-/* Zaptel compile time options */
+/* DAHDI compile time options */
/*
* Uncomment if you have a European phone, or any other phone with a
@@ -48,11 +48,11 @@
/*
* Define if you want MMX optimizations in zaptel
*
- * Note: CONFIG_ZAPTEL_MMX is generally incompatible with AMD
+ * Note: CONFIG_DAHDI_MMX is generally incompatible with AMD
* processors and can cause system instability!
*
*/
-/* #define CONFIG_ZAPTEL_MMX */
+/* #define CONFIG_DAHDI_MMX */
/** If defined: the user must define exactly one ECHO_CAN_ var: */
#ifndef ECHO_CAN_FROMENV
@@ -95,7 +95,7 @@
/* We now use the linux kernel config to detect which options to use */
/* You can still override them below */
#if defined(CONFIG_HDLC) || defined(CONFIG_HDLC_MODULE)
-/* #define CONFIG_ZAPATA_NET */ /* NEVER implicitly turn on ZAPATA_NET */
+/* #define CONFIG_DAHDI_NET */ /* NEVER implicitly turn on CONFIG_DAHDI_NET */
#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,4,20)
#define CONFIG_OLD_HDLC_API
#else
@@ -110,17 +110,17 @@
#endif
#endif
#ifdef CONFIG_PPP
-#define CONFIG_ZAPATA_PPP
+#define CONFIG_DAHDI_PPP
#endif
/*
- * Uncomment CONFIG_ZAPATA_NET to enable SyncPPP, CiscoHDLC, and Frame Relay
+ * Uncomment CONFIG_DAHDI_NET to enable SyncPPP, CiscoHDLC, and Frame Relay
* support.
*/
-/* #define CONFIG_ZAPATA_NET */
+/* #define CONFIG_DAHDI_NET */
/*
- * Uncomment CONFIG_OLD_HDLC_API if your are compiling with ZAPATA_NET
+ * Uncomment CONFIG_OLD_HDLC_API if your are compiling with CONFIG_DAHDI_NET
* defined and you are using the old kernel HDLC interface (or if you get
* an error about ETH_P_HDLC while compiling).
*/
@@ -129,12 +129,12 @@
/*
* Uncomment for Generic PPP support (i.e. ZapRAS)
*/
-/* #define CONFIG_ZAPATA_PPP */
+/* #define CONFIG_DAHDI_PPP */
/*
* Uncomment to enable "watchdog" to monitor if interfaces
* stop taking interrupts or otherwise misbehave
*/
-/* #define CONFIG_ZAPTEL_WATCHDOG */
+/* #define CONFIG_DAHDI_WATCHDOG */
/*
* Uncomment for Non-standard FXS groundstart start state (A=Low, B=Low)
@@ -187,7 +187,7 @@
* Enable sync_tick() calls. Allows low-level drivers to synchronize
* their internal clocks to the zaptel master clock.
*/
-#define ZAPTEL_SYNC_TICK
+#define DAHDI_SYNC_TICK
/*
* Skip processing PCM if low-level driver won't use it anyway
diff --git a/drivers/dahdi/dahdi_dummy.c b/drivers/dahdi/dahdi_dummy.c
index 3e83721..bd08863 100644
--- a/drivers/dahdi/dahdi_dummy.c
+++ b/drivers/dahdi/dahdi_dummy.c
@@ -1,5 +1,5 @@
/*
- * Dummy Zaptel Driver for Zapata Telephony interface
+ * Dummy DAHDI Driver for Zapata Telephony interface
*
* Required: usb-uhci module and kernel > 2.4.4 OR kernel > 2.6.0
*
@@ -263,9 +263,9 @@ extern uhci_t **uhci_devices;
#endif
-#define ZAPTEL_RATE 1000 /* zaptel ticks per second */
-#define ZAPTEL_TIME (1000000 / ZAPTEL_RATE) /* zaptel tick time in us */
-#define ZAPTEL_TIME_NS (ZAPTEL_TIME * 1000) /* zaptel tick time in ns */
+#define DAHDI_RATE 1000 /* zaptel ticks per second */
+#define DAHDI_TIME (1000000 / DAHDI_RATE) /* zaptel tick time in us */
+#define DAHDI_TIME_NS (DAHDI_TIME * 1000) /* zaptel tick time in ns */
/* Different bits of the debug variable: */
#define DEBUG_GENERAL (1 << 0)
@@ -302,7 +302,7 @@ static void ztdummy_rtc_interrupt(void *private_data)
/* Is spinlock required here??? */
spin_lock_irqsave(&ztd->rtclock, flags);
- ztd->counter += ZAPTEL_TIME;
+ ztd->counter += DAHDI_TIME;
while (ztd->counter >= current_rate) {
ztd->counter -= current_rate;
/* Update of RTC IRQ rate isn't possible from interrupt handler :( */
@@ -320,7 +320,7 @@ static enum hrtimer_restart ztdummy_hr_int(struct hrtimer *htmr)
{
unsigned long overrun;
- /* Trigger Zaptel */
+ /* Trigger DAHDI */
dahdi_receive(&ztd->span);
dahdi_transmit(&ztd->span);
@@ -329,7 +329,7 @@ static enum hrtimer_restart ztdummy_hr_int(struct hrtimer *htmr)
* We should worry if overrun is 2 or more; then we really missed
* a tick */
overrun = hrtimer_forward(&zaptimer, htmr->expires,
- ktime_set(0, ZAPTEL_TIME_NS));
+ ktime_set(0, DAHDI_TIME_NS));
if(overrun > 1) {
if(printk_ratelimit())
printk(KERN_NOTICE "ztdummy: HRTimer missed %lu ticks\n",
@@ -354,7 +354,7 @@ static void ztdummy_timer(unsigned long param)
timer.expires = jiffies + 1;
add_timer(&timer);
- ztd->counter += ZAPTEL_TIME;
+ ztd->counter += DAHDI_TIME;
while (ztd->counter >= HZ) {
ztd->counter -= HZ;
dahdi_receive(&ztd->span);
@@ -390,7 +390,7 @@ static int ztdummy_initialize(struct ztdummy *ztd)
sprintf(ztd->span.name, "ZTDUMMY/1");
snprintf(ztd->span.desc, sizeof(ztd->span.desc) - 1, "%s (source: " CLOCK_SRC ") %d", ztd->span.name, 1);
sprintf(ztd->chan.name, "ZTDUMMY/%d/%d", 1, 0);
- dahdi_copy_string(ztd->span.devicetype, "Zaptel Dummy Timing Driver", sizeof(ztd->span.devicetype));
+ dahdi_copy_string(ztd->span.devicetype, "DAHDI Dummy Timing Driver", sizeof(ztd->span.devicetype));
ztd->chan.chanpos = 1;
ztd->span.chans = &ztd->chan;
ztd->span.channels = 0; /* no channels on our span */
@@ -471,7 +471,7 @@ int init_module(void)
zaptimer.function = ztdummy_hr_int;
printk(KERN_DEBUG "ztdummy: Starting High Resolution Timer\n");
- hrtimer_start(&zaptimer, ktime_set(0, ZAPTEL_TIME_NS), HRTIMER_MODE_REL);
+ hrtimer_start(&zaptimer, ktime_set(0, DAHDI_TIME_NS), HRTIMER_MODE_REL);
printk(KERN_INFO "ztdummy: High Resolution Timer started, good to go\n");
#else
init_timer(&timer);
@@ -550,7 +550,7 @@ MODULE_PARM(debug, "i");
#ifndef LINUX26
MODULE_PARM(monitor, "i");
#endif
-MODULE_DESCRIPTION("Dummy Zaptel Driver");
+MODULE_DESCRIPTION("Dummy DAHDI Driver");
MODULE_AUTHOR("Robert Pleh <robert.pleh@hermes.si>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
diff --git a/drivers/dahdi/dahdi_dummy.h b/drivers/dahdi/dahdi_dummy.h
index 0f027cf..c829fba 100644
--- a/drivers/dahdi/dahdi_dummy.h
+++ b/drivers/dahdi/dahdi_dummy.h
@@ -1,5 +1,5 @@
/*
- * Dummy Zaptel Driver for Zapata Telephony interface
+ * Dummy DAHDI Driver for Zapata Telephony interface
*
* Written by Robert Pleh <robert.pleh@hermes.si>
*
diff --git a/drivers/dahdi/dahdi_dynamic_loc.c b/drivers/dahdi/dahdi_dynamic_loc.c
index d5ee144..e475166 100644
--- a/drivers/dahdi/dahdi_dynamic_loc.c
+++ b/drivers/dahdi/dahdi_dynamic_loc.c
@@ -1,5 +1,5 @@
/*
- * Dynamic Span Interface for Zaptel (Local Interface)
+ * Dynamic Span Interface for DAHDI (Local Interface)
*
* Written by Nicolas Bougues <nbougues@axialys.net>
*
diff --git a/drivers/dahdi/hpec/hpec_dahdi.h b/drivers/dahdi/hpec/hpec_dahdi.h
index 9a98b1a..6fc4d39 100644
--- a/drivers/dahdi/hpec/hpec_dahdi.h
+++ b/drivers/dahdi/hpec/hpec_dahdi.h
@@ -20,8 +20,8 @@
* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
-#if !defined(_HPEC_ZAPTEL_H)
-#define _HPEC_ZAPTEL_H
+#if !defined(_HPEC_DAHDI_H)
+#define _HPEC_DAHDI_H
#define DAHDI_EC_ARRAY_UPDATE
@@ -61,7 +61,7 @@ static void memfree(void *ptr)
static void echo_can_init(void)
{
- printk("Zaptel Echo Canceller: Digium High-Performance Echo Canceller\n");
+ printk("DAHDI Echo Canceller: Digium High-Performance Echo Canceller\n");
hpec_init(logger, debug, DAHDI_CHUNKSIZE, memalloc, memfree);
}
@@ -143,4 +143,4 @@ static int hpec_license_ioctl(unsigned int cmd, unsigned long data)
}
}
-#endif /* !defined(_HPEC_ZAPTEL_H) */
+#endif /* !defined(_HPEC_DAHDI_H) */
diff --git a/drivers/dahdi/jpah.h b/drivers/dahdi/jpah.h
index d52f1cf..72b4d00 100644
--- a/drivers/dahdi/jpah.h
+++ b/drivers/dahdi/jpah.h
@@ -44,7 +44,7 @@ struct echo_can_state {
static void echo_can_init(void)
{
- printk("Zaptel Audio Hoser: JP1\n");
+ printk("DAHDI Audio Hoser: JP1\n");
}
static void echo_can_identify(char *buf, size_t len)
diff --git a/drivers/dahdi/kb1ec.h b/drivers/dahdi/kb1ec.h
index 936090b..e56e89e 100644
--- a/drivers/dahdi/kb1ec.h
+++ b/drivers/dahdi/kb1ec.h
@@ -135,7 +135,7 @@ struct echo_can_state {
static void echo_can_init(void)
{
- printk("Zaptel Echo Canceller: KB1\n");
+ printk("DAHDI Echo Canceller: KB1\n");
}
static void echo_can_identify(char *buf, size_t len)
diff --git a/drivers/dahdi/mg2ec.h b/drivers/dahdi/mg2ec.h
index 7d61090..55a7caa 100644
--- a/drivers/dahdi/mg2ec.h
+++ b/drivers/dahdi/mg2ec.h
@@ -161,7 +161,7 @@ struct echo_can_state {
static void echo_can_init(void)
{
- printk("Zaptel Echo Canceller: MG2\n");
+ printk("DAHDI Echo Canceller: MG2\n");
}
static void echo_can_identify(char *buf, size_t len)
diff --git a/drivers/dahdi/pciradio.c b/drivers/dahdi/pciradio.c
index 1abb3d3..251d089 100644
--- a/drivers/dahdi/pciradio.c
+++ b/drivers/dahdi/pciradio.c
@@ -28,11 +28,11 @@
/*
The PCI Radio Interface card interfaces up to 4 two-way radios (either
- a base/mobile radio or repeater system) to Zaptel channels. The driver
+ a base/mobile radio or repeater system) to DAHDI channels. The driver
may work either independent of an application, or with it, through
the driver;s ioctl() interface. This file gives you access to specify
load-time parameters for Radio channels, so that the driver may run
- by itself, and just act like a generic Zaptel radio interface.
+ by itself, and just act like a generic DAHDI radio interface.
*/
/* Latency tests:
@@ -1922,7 +1922,7 @@ module_param(debug, int, 0600);
MODULE_PARM(debug, "i");
#endif
-MODULE_DESCRIPTION("Zapata Telephony PCI Radio Card Zaptel Driver");
+MODULE_DESCRIPTION("Zapata Telephony PCI Radio Card DAHDI Driver");
MODULE_AUTHOR("Jim Dixon <jim@lambdatel.com>");
#ifdef MODULE_LICENSE
diff --git a/drivers/dahdi/sec-2.h b/drivers/dahdi/sec-2.h
index 6a70e3c..2a498e1 100644
--- a/drivers/dahdi/sec-2.h
+++ b/drivers/dahdi/sec-2.h
@@ -36,8 +36,8 @@
Improve double talk detector (iterative!)
*/
-#ifndef _ZAPTEL_SEC_H
-#define _ZAPTEL_SEC_H
+#ifndef _DAHDI_SEC_H
+#define _DAHDI_SEC_H
#ifdef __KERNEL__
#include <linux/kernel.h>
@@ -102,7 +102,7 @@ static int16_t echo_can_update(struct echo_can_state *ec, int16_t tx, int16_t rx
static void echo_can_init(void)
{
- printk("Zaptel Echo Canceller: STEVE2%s\n", ZAPTEL_ECHO_AGGRESSIVE);
+ printk("DAHDI Echo Canceller: STEVE2%s\n", DAHDI_ECHO_AGGRESSIVE);
}
static void echo_can_identify(char *buf, size_t len)
diff --git a/drivers/dahdi/sec.h b/drivers/dahdi/sec.h
index 62213ec..4c8bd69 100644
--- a/drivers/dahdi/sec.h
+++ b/drivers/dahdi/sec.h
@@ -37,8 +37,8 @@
Improve double talk detector (iterative!)
*/
-#ifndef _ZAPTEL_SEC_H
-#define _ZAPTEL_SEC_H
+#ifndef _DAHDI_SEC_H
+#define _DAHDI_SEC_H
#ifdef __KERNEL__
#include <linux/kernel.h>
@@ -102,7 +102,7 @@ struct echo_can_state
static void echo_can_init(void)
{
- printk("Zaptel Echo Canceller: STEVE%s\n", ZAPTEL_ECHO_AGGRESSIVE);
+ printk("DAHDI Echo Canceller: STEVE%s\n", DAHDI_ECHO_AGGRESSIVE);
}
static void echo_can_identify(char *buf, size_t len)
diff --git a/drivers/dahdi/wcfxo.c b/drivers/dahdi/wcfxo.c
index d08f658..305b18a 100644
--- a/drivers/dahdi/wcfxo.c
+++ b/drivers/dahdi/wcfxo.c
@@ -1092,7 +1092,7 @@ MODULE_PARM(boost, "i");
MODULE_PARM(monitor, "i");
MODULE_PARM(opermode, "i");
#endif
-MODULE_DESCRIPTION("Wildcard X100P Zaptel Driver");
+MODULE_DESCRIPTION("Wildcard X100P DAHDI Driver");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
diff --git a/drivers/dahdi/wct1xxp.c b/drivers/dahdi/wct1xxp.c
index f2aedc1..1fcd843 100644
--- a/drivers/dahdi/wct1xxp.c
+++ b/drivers/dahdi/wct1xxp.c
@@ -1426,7 +1426,7 @@ module_param(debug, int, 0600);
#else
MODULE_PARM(debug, "i");
#endif
-MODULE_DESCRIPTION("Wildcard T100P/E100P Zaptel Driver");
+MODULE_DESCRIPTION("Wildcard T100P/E100P DAHDI Driver");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
diff --git a/drivers/dahdi/wct4xxp/base.c b/drivers/dahdi/wct4xxp/base.c
index 23b4b0b..78bdb29 100644
--- a/drivers/dahdi/wct4xxp/base.c
+++ b/drivers/dahdi/wct4xxp/base.c
@@ -1774,7 +1774,7 @@ static int __t4_findsync(struct t4 *wc)
unsigned long flags;
int p;
int nonzero;
- int newsyncsrc = 0; /* Zaptel span number */
+ int newsyncsrc = 0; /* DAHDI span number */
int newsyncnum = 0; /* wct4xxp card number */
int newsyncspan = 0; /* span on given wct4xxp card */
spin_lock_irqsave(&synclock, flags);
diff --git a/drivers/dahdi/wctc4xxp/base.c b/drivers/dahdi/wctc4xxp/base.c
index 37bdfa2..f6b9c98 100644
--- a/drivers/dahdi/wctc4xxp/base.c
+++ b/drivers/dahdi/wctc4xxp/base.c
@@ -1828,7 +1828,7 @@ static int __devinit wcdte_init_one(struct pci_dev *pdev, const struct pci_devic
dahdi_transcoder_register(uencode);
dahdi_transcoder_register(udecode);
- printk("Zaptel DTE (%s) Transcoder support LOADED (firm ver = %d.%d)\n", wc->complexname, dte_firmware_ver, dte_firmware_ver_minor);
+ printk("DAHDI DTE (%s) Transcoder support LOADED (firm ver = %d.%d)\n", wc->complexname, dte_firmware_ver, dte_firmware_ver_minor);
/* Enable bus mastering */
diff --git a/drivers/dahdi/wctc4xxp/codec_test.c b/drivers/dahdi/wctc4xxp/codec_test.c
index 0afcebf..abea9e9 100644
--- a/drivers/dahdi/wctc4xxp/codec_test.c
+++ b/drivers/dahdi/wctc4xxp/codec_test.c
@@ -100,7 +100,7 @@ static int find_transcoders(struct tctest_info *tctest_info)
int fd, res;
if ((fd = open("/dev/zap/transcode", O_RDWR)) < 0) {
- printf("Warning: No Zaptel transcoder support!\n");
+ printf("Warning: No DAHDI transcoder support!\n");
return 0;
}
diff --git a/drivers/dahdi/wctdm.c b/drivers/dahdi/wctdm.c
index e14eb73..970c939 100644
--- a/drivers/dahdi/wctdm.c
+++ b/drivers/dahdi/wctdm.c
@@ -2548,7 +2548,7 @@ MODULE_PARM(fxorxgain, "i");
MODULE_PARM(fxstxgain, "i");
MODULE_PARM(fxsrxgain, "i");
#endif
-MODULE_DESCRIPTION("Wildcard TDM400P Zaptel Driver");
+MODULE_DESCRIPTION("Wildcard TDM400P DAHDI Driver");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#if defined(MODULE_ALIAS)
MODULE_ALIAS("wcfxs");
diff --git a/drivers/dahdi/wctdm24xxp/base.c b/drivers/dahdi/wctdm24xxp/base.c
index 9cd3ae4..f1a749e 100644
--- a/drivers/dahdi/wctdm24xxp/base.c
+++ b/drivers/dahdi/wctdm24xxp/base.c
@@ -4052,7 +4052,7 @@ MODULE_PARM(vpmnlpthresh, "i");
MODULE_PARM(vpmnlpmaxsupp, "i");
#endif
#endif
-MODULE_DESCRIPTION("Wildcard TDM2400P/TDM800P Zaptel Driver");
+MODULE_DESCRIPTION("Wildcard TDM2400P/TDM800P DAHDI Driver");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#if defined(MODULE_ALIAS)
MODULE_ALIAS("wctdm8xxp");
diff --git a/drivers/dahdi/wcte11xp.c b/drivers/dahdi/wcte11xp.c
index ca7a9c2..c928f9e 100644
--- a/drivers/dahdi/wcte11xp.c
+++ b/drivers/dahdi/wcte11xp.c
@@ -1637,7 +1637,7 @@ MODULE_PARM(clockextra, "i");
MODULE_PARM(debug, "i");
MODULE_PARM(j1mode, "i");
#endif
-MODULE_DESCRIPTION("Wildcard TE110P Zaptel Driver");
+MODULE_DESCRIPTION("Wildcard TE110P DAHDI Driver");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
diff --git a/drivers/dahdi/wcte12xp/base.c b/drivers/dahdi/wcte12xp/base.c
index 1bff18a..20f2da5 100644
--- a/drivers/dahdi/wcte12xp/base.c
+++ b/drivers/dahdi/wcte12xp/base.c
@@ -1172,7 +1172,7 @@ static int t1_software_init(struct t1 *wc)
wc->chans[x].chanpos = x + 1;
}
if (dahdi_register(&wc->span, 0)) {
- module_printk("Unable to register span with Zaptel\n");
+ module_printk("Unable to register span with DAHDI\n");
return -1;
}
wc->initialized = 1;
diff --git a/include/dahdi/kernel.h b/include/dahdi/kernel.h
index e64ed9c..745eff1 100644
--- a/include/dahdi/kernel.h
+++ b/include/dahdi/kernel.h
@@ -25,8 +25,8 @@
* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
-#ifndef _LINUX_ZAPTEL_H
-#define _LINUX_ZAPTEL_H
+#ifndef _LINUX_DAHDI_H
+#define _LINUX_DAHDI_H
#ifdef __KERNEL__
#include "dahdi_config.h"
@@ -37,11 +37,11 @@
#include <linux/fs.h>
#include <linux/ioctl.h>
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
#include <linux/hdlc.h>
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
#include <linux/ppp_channel.h>
#include <linux/skbuff.h>
#include <linux/interrupt.h>
@@ -85,7 +85,7 @@
#include <linux/devfs_fs_kernel.h>
#else
#undef CONFIG_DEVFS_FS
-//#warning "Zaptel doesn't support DEVFS in post 2.4 kernels. Disabling DEVFS in zaptel"
+//#warning "DAHDI doesn't support DEVFS in post 2.4 kernels. Disabling DEVFS in zaptel"
#endif
#endif /* CONFIG_DEVFS_FS */
#endif /* __KERNEL__ */
@@ -725,7 +725,7 @@ struct dahdi_hwgain{
/*
- * Get the version of Zaptel that is running, and a description
+ * Get the version of DAHDI that is running, and a description
* of the compiled-in echo canceller (if any)
*/
#define DAHDI_GETVERSION _IOR(DAHDI_CODE, 57, struct dahdi_versioninfo)
@@ -1257,7 +1257,7 @@ struct dahdi_chardev {
int dahdi_register_chardev(struct dahdi_chardev *dev);
int dahdi_unregister_chardev(struct dahdi_chardev *dev);
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
struct dahdi_hdlc {
#ifdef LINUX26
struct net_device *netdev;
@@ -1303,11 +1303,11 @@ typedef struct
} sf_detect_state_t;
struct dahdi_chan {
-#ifdef CONFIG_ZAPATA_NET
+#ifdef CONFIG_DAHDI_NET
/* Must be first */
struct dahdi_hdlc *hdlcnetdev;
#endif
-#ifdef CONFIG_ZAPATA_PPP
+#ifdef CONFIG_DAHDI_PPP
struct ppp_channel *ppp;
struct tasklet_struct ppp_calls;
int do_ppp_wakeup;
@@ -1317,7 +1317,7 @@ struct dahdi_chan {
spinlock_t lock;
char name[40]; /* Name */
/* Specified by zaptel */
- int channo; /* Zaptel Channel number */
+ int channo; /* DAHDI Channel number */
int chanpos;
unsigned long flags;
long rxp1;
@@ -1634,7 +1634,7 @@ struct dahdi_span {
/* Opt: Enable maintenance modes */
int (*maint)(struct dahdi_span *span, int mode);
-#ifdef ZAPTEL_SYNC_TICK
+#ifdef DAHDI_SYNC_TICK
/* Opt: send sync to spans */
int (*sync_tick)(struct dahdi_span *span, int is_master);
#endif
@@ -1694,7 +1694,7 @@ struct dahdi_span {
/* If the watchdog detects no received data, it will call the
watchdog routine */
int (*watchdog)(struct dahdi_span *span, int cause);
-#ifdef CONFIG_ZAPTEL_WATCHDOG
+#ifdef CONFIG_DAHDI_WATCHDOG
int watchcounter;
int watchstate;
#endif
@@ -1815,10 +1815,10 @@ int dahdi_unregister(struct dahdi_span *span);
/* Gives a name to an LBO */
char *dahdi_lboname(int lbo);
-/* Tell Zaptel about changes in received rbs bits */
+/* Tell DAHDI about changes in received rbs bits */
void dahdi_rbsbits(struct dahdi_chan *chan, int bits);
-/* Tell Zaptel abou changes in received signalling */
+/* Tell DAHDI abou changes in received signalling */
void dahdi_hooksig(struct dahdi_chan *chan, dahdi_rxsig_t rxsig);
/* Queue an event on a channel */
@@ -1842,7 +1842,7 @@ struct dahdi_tone *dahdi_mf_tone(const struct dahdi_chan *chan, char digit, int
/* Echo cancel a receive and transmit chunk for a given channel. This
should be called by the low-level driver as close to the interface
as possible. ECHO CANCELLATION IS NO LONGER AUTOMATICALLY DONE
- AT THE ZAPTEL LEVEL. dahdi_ec_chunk will not echo cancel if it should
+ AT THE DAHDI LEVEL. dahdi_ec_chunk will not echo cancel if it should
not be doing so. rxchunk is modified in-place */
void dahdi_ec_chunk(struct dahdi_chan *chan, unsigned char *rxchunk, const unsigned char *txchunk);
@@ -2104,4 +2104,4 @@ static inline void dahdi_copy_string(char *dst, const char *src, unsigned int si
*dst = '\0';
}
-#endif /* _LINUX_ZAPTEL_H */
+#endif /* _LINUX_DAHDI_H */
diff --git a/drivers/dahdi/dahdi_dynamic.c b/drivers/dahdi/dahdi_dynamic.c
index 2fa8a61..14bb913 100644
--- a/drivers/dahdi/dahdi_dynamic.c
+++ b/drivers/dahdi/dahdi_dynamic.c
@@ -1,5 +1,5 @@
/*
* Dynamic Span Interface for Zaptel
*
* Written by Mark Spencer <markster@digium.com>
*
@@ -837,7 +837,7 @@ int ztdynamic_init(void)
#ifdef ENABLE_TASKLETS
tasklet_init(&ztd_tlet, ztd_tasklet, 0);
#endif
- printk("Zaptel Dynamic Span support LOADED\n");
+ printk("DAHDI Dynamic Span support LOADED\n");
return 0;
}
@@ -851,7 +851,7 @@ void ztdynamic_cleanup(void)
#endif
dahdi_set_dynamic_ioctl(NULL);
del_timer(&alarmcheck);
- printk("Zaptel Dynamic Span support unloaded\n");
+ printk("DAHDI Dynamic Span support unloaded\n");
}
#ifdef LINUX26
@@ -859,7 +859,7 @@ module_param(debug, int, 0600);
#else
MODULE_PARM(debug, "i");
#endif
-MODULE_DESCRIPTION("Zaptel Dynamic Span Support");
+MODULE_DESCRIPTION("DAHDI Dynamic Span Support");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
/*
- * Dynamic Span Interface for Zaptel
+ * Dynamic Span Interface for DAHDI
*
* Written by Mark Spencer <markster@digium.com>
diff --git a/drivers/dahdi/dahdi_dynamic_eth.c b/drivers/dahdi/dahdi_dynamic_eth.c
index e840904..e09da00 100644
--- a/drivers/dahdi/dahdi_dynamic_eth.c
+++ b/drivers/dahdi/dahdi_dynamic_eth.c
@@ -1,5 +1,5 @@
/*
* Dynamic Span Interface for Zaptel (Ethernet Interface)
*
* Written by Mark Spencer <markster@digium.com>
*
@@ -439,7 +439,7 @@ static void __exit ztdeth_exit(void)
dahdi_dynamic_unregister(&ztd_eth);
}
-MODULE_DESCRIPTION("Zaptel Dynamic TDMoE Support");
+MODULE_DESCRIPTION("DAHDI Dynamic TDMoE Support");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
/*
- * Dynamic Span Interface for Zaptel (Ethernet Interface)
+ * Dynamic Span Interface for DAHDI (Ethernet Interface)
*
* Written by Mark Spencer <markster@digium.com>
diff --git a/drivers/dahdi/dahdi_transcode.c b/drivers/dahdi/dahdi_transcode.c
index d6c27bb..95f6a24 100644
--- a/drivers/dahdi/dahdi_transcode.c
+++ b/drivers/dahdi/dahdi_transcode.c
@@ -1,5 +1,5 @@
/*
* Transcoder Interface for Zaptel
*
* Written by Mark Spencer <markster@digium.com>
*
@@ -461,7 +461,7 @@ int zttranscode_init(void)
if ((res = dahdi_register_chardev(&transcode_chardev)))
return res;
- printk("Zaptel Transcoder support loaded\n");
+ printk("DAHDI Transcoder support loaded\n");
return 0;
}
@@ -472,7 +472,7 @@ void zttranscode_cleanup(void)
dahdi_transcode_fops = NULL;
- printk("Zaptel Transcoder support unloaded\n");
+ printk("DAHDI Transcoder support unloaded\n");
}
#ifdef LINUX26
@@ -480,7 +480,7 @@ module_param(debug, int, S_IRUGO | S_IWUSR);
#else
MODULE_PARM(debug, "i");
#endif
-MODULE_DESCRIPTION("Zaptel Transcoder Support");
+MODULE_DESCRIPTION("DAHDI Transcoder Support");
MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
/*
- * Transcoder Interface for Zaptel
+ * Transcoder Interface for DAHDI
*
* Written by Mark Spencer <markster@digium.com>
diff --git a/drivers/dahdi/tor2.c b/drivers/dahdi/tor2.c
index 85345f4..cfd8147 100644
--- a/drivers/dahdi/tor2.c
+++ b/drivers/dahdi/tor2.c
@@ -1111,7 +1111,7 @@ static int tor2_findsync(struct tor2 *tor)
unsigned long flags;
int p;
int nonzero;
- int newsyncsrc = 0; /* Zaptel span number */
+ int newsyncsrc = 0; /* DAHDI span number */
int newsyncnum = 0; /* tor2 card number */
int newsyncspan = 0; /* span on given tor2 card */
spin_lock_irqsave(&synclock, flags);
@@ -1500,7 +1500,7 @@ static int tor2_ioctl(struct dahdi_chan *chan, unsigned int cmd, unsigned long d
}
MODULE_AUTHOR("Mark Spencer");
-MODULE_DESCRIPTION("Tormenta 2 PCI Quad T1 or E1 Zaptel Driver");
+MODULE_DESCRIPTION("Tormenta 2 PCI Quad T1 or E1 DAHDI Driver");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
#endif